pub struct Diagnostics {
pub resolved_units: u64,
pub unresolved_units: u64,
pub resolved_weapons: u64,
pub unresolved_weapons: u64,
pub warnings: Vec<Warning>,
}Expand description
A summary of what resolved and what did not during the import.
Fields
resolved_units: u64unresolved_units: u64resolved_weapons: u64unresolved_weapons: u64warnings: Vec<Warning>Trait Implementations
Sourceimpl Clone for Diagnostics
impl Clone for Diagnostics
Sourcefn clone(&self) -> Diagnostics
fn clone(&self) -> Diagnostics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Diagnostics
impl Debug for Diagnostics
Sourceimpl<'de> Deserialize<'de> for Diagnostics
impl<'de> Deserialize<'de> for Diagnostics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Diagnostics
impl PartialEq for Diagnostics
Sourcefn eq(&self, other: &Diagnostics) -> bool
fn eq(&self, other: &Diagnostics) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Diagnostics
impl Serialize for Diagnostics
impl StructuralPartialEq for Diagnostics